@@ -7,7 +7,10 @@
  ***********************************************************************/
 
 #include "mainContext.h"
-
+#include "ki18n_version.h"
+#if KI18N_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+#include <KLocalizedQmlContext>
+#endif
 #include <KAboutData>
 #include <KIO/Global> // upUrl
 #include <KLocalizedString>
@@ -33,19 +36,6 @@ using namespace Qt::StringLiterals;
 namespace Filelight
 {
 
-class About : public QObject
-{
-    Q_OBJECT
-    Q_PROPERTY(KAboutData data READ data CONSTANT)
-    [[nodiscard]] static KAboutData data()
-    {
-        return KAboutData::applicationData();
-    }
-
-public:
-    using QObject::QObject;
-};
-
 MainContext::MainContext(QObject *parent)
     : QObject(parent)
     , m_manager(new ScanManager(this))
@@ -54,17 +44,19 @@ MainContext::MainContext(QObject *parent)
 
     auto engine = new QQmlApplicationEngine(this);
 
+#if KI18N_VERSION < QT_VERSION_CHECK(6, 8, 0)
     static auto l10nContext = new KLocalizedContext(engine);
+#else
+    static auto l10nContext = new KLocalizedQmlContext(engine);
+#endif
     l10nContext->setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
     engine->rootContext()->setContextObject(l10nContext);
 
     qmlRegisterUncreatableMetaObject(Filelight::staticMetaObject, "org.kde.filelight", 1, 0, "Filelight", QStringLiteral("Access to enums & flags only"));
 
-    auto about = new About(this);
     qRegisterMetaType<size_t>("size_t");
     qmlRegisterType<DropperItem>("org.kde.filelight", 1, 0, "DropperItem");
     qmlRegisterType<WindowThemer>("org.kde.filelight", 1, 0, "WindowThemer");
-    qmlRegisterSingletonInstance("org.kde.filelight", 1, 0, "About", about);
     qmlRegisterSingletonInstance("org.kde.filelight", 1, 0, "ScanManager", m_manager);
     qmlRegisterSingletonInstance("org.kde.filelight", 1, 0, "MainContext", this);
     auto fileModel = new FileModel(this);
