@@ -29,14 +29,12 @@ public:
 Q_SIGNALS:
     void branchCompleted(std::shared_ptr<Folder> tree);
 
-private Q_SLOTS:
+private:
     void onCompleted();
     void onCanceled();
-
-private:
     std::shared_ptr<Store> m_root;
     std::shared_ptr<Store> m_store;
-    ScanManager *m_manager;
+    ScanManager *m_manager = nullptr;
     Q_DISABLE_COPY_MOVE(RemoteLister)
 };
 } // namespace Filelight
